@@ -8,7 +8,7 @@
  * This module is not meant to be used on plaforms other than Solaris. As
  * such, trying to compile it elswhere will probably fail with all sorts
  * of errors.
- * 
+ *
  * Some notes on the Solaris syslog mechanism:
  * Both system (kernel) and application log messages are provided via
  * a single message stream.
@@ -24,11 +24,11 @@
  * call is done, and the server process inside rsyslog simply does NOTHING
  * but return. All that Solaris sylsogd() is interested in is if the door
  * server (we) responds and thus can be considered alive. The actual message
- * is then submitted via the usual stream. I have to admit I do not 
+ * is then submitted via the usual stream. I have to admit I do not
  * understand why the message itself is not passed via this high-performance
  * API. But anyhow, that's nothing I can change, so the most important thing
  * is to note how Solaris does this thing ;)
- * The syslog() library call checks syslogd state for *each* call (what a 
+ * The syslog() library call checks syslogd state for *each* call (what a
  * waste of time...) and decides each time if the message should go to the
  * console or not.  According to OpenSolaris sources, it looks like there is
  * message loss potential when the door file is created before all data has
@@ -83,6 +83,7 @@
 #include "msg.h"
 #include "prop.h"
 #include "sun_cddl.h"
+#include "datetime.h"
 
 MODULE_TYPE_INPUT
 MODULE_TYPE_NOKEEP
@@ -94,9 +95,9 @@ MODULE_CNFNAME("imsolaris")
 
 /* Module static data */
 DEF_IMOD_STATIC_DATA
-DEFobjCurrIf(errmsg)
 DEFobjCurrIf(glbl)
 DEFobjCurrIf(prop)
+DEFobjCurrIf(datetime)
 
 
 /* config settings */
@@ -117,7 +118,7 @@ static char *LogName = NULL;	/* the log socket name TODO: make configurable! */
 void
 imsolaris_logerror(int err, char *errStr)
 {
-	errmsg.LogError(err, RS_RET_ERR_DOOR, "%s", errStr);
+	LogError(err, RS_RET_ERR_DOOR, "%s", errStr);
 }
 
 
@@ -142,15 +143,15 @@ tryRecover(void)
 	while(1) { /* loop broken inside */
 		iRet = sun_openklog((LogName == NULL) ? PATH_LOG : LogName);
 		if(iRet == RS_RET_OK) {
-			if(tryNum > 1) {		
-				errmsg.LogError(0, iRet, "failure on system log socket recovered.");
-			}	
+			if(tryNum > 1) {
+				LogError(0, iRet, "failure on system log socket recovered.");
+			}
 			break;
-		}	
+		}
 		/* failure, so sleep a bit. We wait try*10 ms, with a max of 15 seconds */
-		if(tryNum == 1) {		
-			errmsg.LogError(0, iRet, "failure on system log socket, trying to recover...");
-		}	
+		if(tryNum == 1) {
+			LogError(0, iRet, "failure on system log socket, trying to recover...");
+		}
 		waitusecs = tryNum * 10000;
 		waitsecs = waitusecs / 1000000;
 		DBGPRINTF("imsolaris: try %d to recover system log socket in %d.%d seconds\n",
@@ -158,12 +159,12 @@ tryRecover(void)
 		if(waitsecs > 15) {
 			waitsecs = 15;
 			waitusecs = 0;
-		} else  {	
+		} else  {
 			waitusecs = waitusecs % 1000000;
-		}	
+		}
 		srSleep(waitsecs, waitusecs);
 		++tryNum;
-	}	
+	}
 }
 
 
@@ -181,6 +182,7 @@ readLog(int fd, uchar *pRcv, int iMaxLine)
 	struct strbuf data;
 	struct strbuf ctl;
 	struct log_ctl hdr;
+	struct timeval tim;
 	int flags;
 	smsg_t *pMsg;
 	int ret;
@@ -199,9 +201,9 @@ readLog(int fd, uchar *pRcv, int iMaxLine)
 			int en = errno;
 			rs_strerror_r(errno, errStr, sizeof(errStr));
 			DBGPRINTF("imsolaris: stream input error on fd %d: %s.\n", fd, errStr);
-			errmsg.LogError(en, NO_ERRCODE, "imsolaris: stream input error: %s", errStr);
+			LogError(en, NO_ERRCODE, "imsolaris: stream input error: %s", errStr);
 			tryRecover();
-		}	
+		}
 	} else {
 		DBGPRINTF("imsolaris: message from log stream %d: %s\n", fd, pRcv);
 		pRcv[data.len] = '\0'; /* make sure it is a valid C-String */
@@ -210,7 +212,12 @@ readLog(int fd, uchar *pRcv, int iMaxLine)
 		MsgSetRawMsg(pMsg, (char*)pRcv, strlen((char*)pRcv));
 		MsgSetHOSTNAME(pMsg, glbl.GetLocalHostName(), ustrlen(glbl.GetLocalHostName()));
 		msgSetPRI(pMsg, hdr.pri);
-		pMsg->msgFlags = NEEDS_PARSING | NO_PRI_IN_RAW;
+		pMsg->msgFlags = NEEDS_PARSING | NO_PRI_IN_RAW | IGNDATE;
+
+		/* Construct timestamp from msg ctl struct */
+		tim.tv_usec = 0;
+		tim.tv_sec = hdr.ttime;
+		datetime.timeval2syslogTime(&tim, &pMsg->tRcvdAt, TIME_IN_LOCALTIME);
 		CHKiRet(submitMsg(pMsg));
 	}
 
@@ -266,15 +273,15 @@ getMsgs(thrdInfo_t *pThrd, int timeout)
 					FINALIZE;
 				} else {
 					continue;
-				}	
-			}		
+				}
+			}
 
 			if(nfds < 0) {
 				if(errno != EINTR) {
 					int en = errno;
 					rs_strerror_r(en, errStr, sizeof(errStr));
 					DBGPRINTF("imsolaris: poll error: %d = %s.\n", errno, errStr);
-					errmsg.LogError(en, NO_ERRCODE, "imsolaris: poll error: %s",
+					LogError(en, NO_ERRCODE, "imsolaris: poll error: %s",
 							errStr);
 				}
 				continue;
@@ -365,7 +372,7 @@ CODESTARTwillRun
 
 	iRet = sun_openklog((LogName == NULL) ? PATH_LOG : LogName);
 	if(iRet != RS_RET_OK) {
-		errmsg.LogError(0, iRet, "error opening system log socket");
+		LogError(0, iRet, "error opening system log socket");
 	}
 finalize_it:
 ENDwillRun
@@ -376,7 +383,7 @@ CODESTARTafterRun
 	/* do cleanup here */
 	if(pInputName != NULL)
 		prop.Destruct(&pInputName);
-	free(LogName);	
+	free(LogName);
 ENDafterRun
 
 
@@ -384,15 +391,15 @@ BEGINmodExit
 CODESTARTmodExit
 	sun_delete_doorfiles();
 	objRelease(glbl, CORE_COMPONENT);
-	objRelease(errmsg, CORE_COMPONENT);
 	objRelease(prop, CORE_COMPONENT);
+	objRelease(datetime, CORE_COMPONENT);
 ENDmodExit
 
 
 BEGINisCompatibleWithFeature
 CODESTARTisCompatibleWithFeature
-        if(eFeat == sFEATURENonCancelInputTermination)
-                iRet = RS_RET_OK;
+	if(eFeat == sFEATURENonCancelInputTermination)
+		iRet = RS_RET_OK;
 ENDisCompatibleWithFeature
 
 
@@ -413,17 +420,17 @@ BEGINmodInit()
 CODESTARTmodInit
 	*ipIFVersProvided = CURR_MOD_IF_VERSION; /* we only support the current interface specification */
 CODEmodInit_QueryRegCFSLineHdlr
-	CHKiRet(objUse(errmsg, CORE_COMPONENT));
 	CHKiRet(objUse(glbl, CORE_COMPONENT));
 	CHKiRet(objUse(prop, CORE_COMPONENT));
+	CHKiRet(objUse(datetime, CORE_COMPONENT));
 
 	DBGPRINTF("imsolaris version %s initializing\n", PACKAGE_VERSION);
 
 	/* register config file handlers */
 	CHKiRet(omsdRegCFSLineHdlr((uchar *)"resetconfigvariables", 1, eCmdHdlrCustomHandler,
 		resetConfigVariables, NULL, STD_LOADABLE_MODULE_ID));
-        CHKiRet(omsdRegCFSLineHdlr((uchar *)"imsolarislogsocketname", 0, eCmdHdlrGetWord,
-                NULL, &LogName, STD_LOADABLE_MODULE_ID));
+	CHKiRet(omsdRegCFSLineHdlr((uchar *)"imsolarislogsocketname", 0, eCmdHdlrGetWord,
+		NULL, &LogName, STD_LOADABLE_MODULE_ID));
 ENDmodInit
 /* vim:set ai:
  */
