@@ -54,6 +54,11 @@ struct nsd_gtls_s {
 		GTLS_EXPIRED_DENY = 1,
 		GTLS_EXPIRED_WARN = 2
 	} permitExpiredCerts;
+	enum {
+		GTLS_NONE = 0,
+		GTLS_PURPOSE = 1
+	} dataTypeCheck;
+	int bSANpriority; /* if true, we do stricter checking (if any SAN present we do not cehck CN) */
 	gtlsRtryCall_t rtryCall;/**< what must we retry? */
 	int bIsInitiator;	/**< 0 if socket is the server end (listener), 1 if it is the initiator */
 	gnutls_session_t sess;
@@ -66,6 +71,7 @@ struct nsd_gtls_s {
 				 * one successful authentication. */
 	permittedPeers_t *pPermPeers; /* permitted peers */
 	uchar *gnutlsPriorityString;	/* gnutls priority string */
+	int DrvrVerifyDepth;		/* Verify Depth for certificate chains */
 	gnutls_x509_crt_t pOurCerts[NSD_GTLS_MAX_CERT];	/**< our certificate, if in client mode
 							(unused in server mode) */
 	unsigned int nOurCerts;  /* number of certificates in our chain */
@@ -99,4 +105,8 @@ rsRetVal gtlsRecordRecv(nsd_gtls_t *pThis);
 #define GTLS_ANON_PRIO "NORMAL:+ANON-DH:+ANON-ECDH:+COMP-ALL"
 #endif
 
+#if GNUTLS_VERSION_MAJOR > 3 || (GNUTLS_VERSION_MAJOR == 3 && GNUTLS_VERSION_MINOR >=4)
+#define EXTENDED_CERT_CHECK_AVAILABLE
+#endif
+
 #endif /* #ifndef INCLUDED_NSD_GTLS_H */
