@@ -3,7 +3,7 @@
  *
  * Begun 2005-09-15 RGerhards
  *
- * Copyright (C) 2005-2018 by Rainer Gerhards and Adiscon GmbH
+ * Copyright (C) 2005-2019 by Rainer Gerhards and Adiscon GmbH
  *
  * This file is part of the rsyslog runtime library.
  *
@@ -87,7 +87,6 @@
 
 #if defined(__GNUC__)
 	#define PRAGMA_INGORE_Wswitch_enum	_Pragma("GCC diagnostic ignored \"-Wswitch-enum\"")
-	#define PRAGMA_IGNORE_Wcast_align	_Pragma("GCC diagnostic ignored \"-Wcast-align\"")
 	#define PRAGMA_IGNORE_Wempty_body	_Pragma("GCC diagnostic ignored \"-Wempty-body\"")
 	#define PRAGMA_IGNORE_Wsign_compare	_Pragma("GCC diagnostic ignored \"-Wsign-compare\"")
 	#define PRAGMA_IGNORE_Wpragmas		_Pragma("GCC diagnostic ignored \"-Wpragmas\"")
@@ -106,7 +105,6 @@
 	#define PRAGMA_DIAGNOSTIC_POP		_Pragma("GCC diagnostic pop")
 #else
 	#define PRAGMA_INGORE_Wswitch_enum
-	#define PRAGMA_IGNORE_Wcast_align
 	#define PRAGMA_IGNORE_Wsign_compare
 	#define PRAGMA_IGNORE_Wformat_nonliteral
 	#define PRAGMA_IGNORE_Wpragmas
@@ -200,7 +198,9 @@
 #define	LOG_LPR		(6<<3)	/* line printer subsystem */
 #define	LOG_NEWS	(7<<3)	/* network news subsystem */
 #define	LOG_UUCP	(8<<3)	/* UUCP subsystem */
+#if !defined(LOG_CRON)
 #define	LOG_CRON	(9<<3)	/* clock daemon */
+#endif
 #define	LOG_AUTHPRIV	(10<<3)	/* security/authorization messages (private) */
 #define	LOG_FTP		(11<<3)	/* ftp daemon */
 #if defined(_AIX)		/* AIXPORT : These are necessary for AIX */
@@ -604,8 +604,12 @@ enum rsRetVal_				/** return value. All methods return this if not specified oth
  */
 #ifdef HAVE_BUILTIN_EXCEPT
 #	define CHKiRet(code) if(__builtin_expect(((iRet = code) != RS_RET_OK), 0)) goto finalize_it
+#	define likely(x)      __builtin_expect(!!(x), 1)
+#	define unlikely(x)    __builtin_expect(!!(x), 0)
 #else
 #	define CHKiRet(code) if((iRet = code) != RS_RET_OK) goto finalize_it
+#	define likely(x)      (x)
+#	define unlikely(x)    (x)
 #endif
 
 # define CHKiConcCtrl(code)  { int tmp_CC; \
