@@ -3,7 +3,7 @@
 echo ======================================================================
 echo [imfile-endregex-save-lf-persist.sh]
 . $srcdir/diag.sh check-inotify
-. $srcdir/diag.sh init
+. ${srcdir:=.}/diag.sh init
 generate_conf
 add_conf '
 module(load="../plugins/imfile/.libs/imfile")
