@@ -1,7 +1,7 @@
 #!/bin/bash
 # test if HUP works for impstats
 # This file is part of the rsyslog project, released under ASL 2.0
-. $srcdir/diag.sh init
+. ${srcdir:=.}/diag.sh init
 generate_conf
 add_conf '
 module(load="../plugins/impstats/.libs/impstats"
