@@ -2,7 +2,7 @@
 # Note: this test tests if we die when recursively include the same
 # file ever again. This is a user error, but we should detect it.
 # This file is part of the rsyslog project, released  under ASL 2.0
-. $srcdir/diag.sh init
+. ${srcdir:=.}/diag.sh init
 generate_conf
 echo '$IncludeConfig '${RSYSLOG_DYNNAME}'work-nested.conf
 ' > ${RSYSLOG_DYNNAME}work-nested.conf
