@@ -1,7 +1,7 @@
 #!/bin/bash
 # added 2018-04-06 by richm, released under ASL 2.0
 #
-# Note: on buidbot VMs (where there is no environment cleanup), the
+# Note: on buildbot VMs (where there is no environment cleanup), the
 # kubernetes test server may be kept running if the script aborts or
 # is aborted (buildbot master failure!) for some reason. As such we
 # execute it under "timeout" control, which ensure it always is
@@ -38,7 +38,7 @@ action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="mmk8s_template")
 
 testsrv=mmk8s-test-server
 echo starting kubernetes \"emulator\"
-timeout 2m python -u $srcdir/mmkubernetes_test_server.py $k8s_srv_port ${RSYSLOG_DYNNAME}${testsrv}.pid ${RSYSLOG_DYNNAME}${testsrv}.started > ${RSYSLOG_DYNNAME}.spool/mmk8s_srv.log 2>&1 &
+timeout 2m $PYTHON -u $srcdir/mmkubernetes_test_server.py $k8s_srv_port ${RSYSLOG_DYNNAME}${testsrv}.pid ${RSYSLOG_DYNNAME}${testsrv}.started > ${RSYSLOG_DYNNAME}.spool/mmk8s_srv.log 2>&1 &
 BGPROCESS=$!
 wait_process_startup ${RSYSLOG_DYNNAME}${testsrv} ${RSYSLOG_DYNNAME}${testsrv}.started
 echo background mmkubernetes_test_server.py process id is $BGPROCESS
@@ -109,7 +109,7 @@ wait_pid_termination ${RSYSLOG_DYNNAME}${testsrv}.pid
 rc=0
 # for each record in mmkubernetes-basic.out.json, see if the matching
 # record is found in $RSYSLOG_OUT_LOG
-python -c 'import sys,json
+$PYTHON -c 'import sys,json
 k8s_srv_port = sys.argv[3]
 expected = {}
 for hsh in json.load(open(sys.argv[1])):
@@ -143,13 +143,15 @@ grep -q 'mmkubernetes: Too Many Requests: the server is too heavily loaded to pr
 grep -q 'mmkubernetes: Too Many Requests: the server is too heavily loaded to provide the data for the requested url .*/pods\\\/pod-name-9-busy' $RSYSLOG_OUT_LOG || { echo fail4; rc=1; }
 
 if [ -f ${RSYSLOG_DYNNAME}.spool/mmkubernetes-stats.log ] ; then
-	python <${RSYSLOG_DYNNAME}.spool/mmkubernetes-stats.log  -c '
+	$PYTHON <${RSYSLOG_DYNNAME}.spool/mmkubernetes-stats.log  -c '
 import sys,json
 k8s_srv_port = sys.argv[1]
 expected = {"name": "mmkubernetes(http://localhost:{0})".format(k8s_srv_port),
     "origin": "mmkubernetes", "recordseen": 12, "namespacemetadatasuccess": 9,
 	"namespacemetadatanotfound": 1, "namespacemetadatabusy": 1, "namespacemetadataerror": 0,
-	"podmetadatasuccess": 9, "podmetadatanotfound": 1, "podmetadatabusy": 2, "podmetadataerror": 0 }
+	"podmetadatasuccess": 9, "podmetadatanotfound": 1, "podmetadatabusy": 2, "podmetadataerror": 0,
+	"namespacecachenumentries": 10, "podcachenumentries": 10, "namespacecachehits": 1,
+	"podcachehits": 0, "namespacecachemisses": 11, "podcachemisses": 12 }
 actual = {}
 for line in sys.stdin:
 	jstart = line.find("{")
