@@ -3,18 +3,15 @@
 # This file is part of the rsyslog project, released  under ASL 2.0
 . ${srcdir:=.}/diag.sh init
 export NUMMESSAGES=1000
-# uncomment for debugging support:
-#export RSYSLOG_DEBUG="debug nostdout noprintmutexaction"
+export QUEUE_EMPTY_CHECK_FUNC=wait_file_lines
 export RSYSLOG_DEBUGLOG="log"
 generate_conf
-export PORT_RCVR="$(get_free_port)"
 add_conf '
 module(	load="../plugins/imtcp/.libs/imtcp"
 	StreamDriver.Name="gtls"
 	StreamDriver.Mode="1"
 	StreamDriver.AuthMode="anon" )
-# then SENDER sends to this port (not tcpflood!)
-input(	type="imtcp" port="'$PORT_RCVR'" )
+input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port" )
 
 $template outfmt,"%msg:F,58:2%\n"
 $template dynfile,"'$RSYSLOG_OUT_LOG'" # trick to use relative path names!
@@ -22,19 +19,14 @@ $template dynfile,"'$RSYSLOG_OUT_LOG'" # trick to use relative path names!
 '
 startup
 export RSYSLOG_DEBUGLOG="log2"
+export RCVR_PORT=$TCPFLOOD_PORT
 #valgrind="valgrind"
 generate_conf 2
-export TCPFLOOD_PORT="$(get_free_port)" 
 add_conf '
-# Note: no TLS for the listener, this is for tcpflood!
-module(	load="../plugins/imtcp/.libs/imtcp")
-input( type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port")
-
-# set up the action
 action(	type="omfwd"
 	protocol="tcp"
 	target="127.0.0.1"
-	port="'$PORT_RCVR'"
+	port="'$RCVR_PORT'"
 	StreamDriver="gtls"
 	StreamDriverMode="1"
 	StreamDriverAuthMode="anon"
@@ -44,8 +36,7 @@ startup 2
 
 # now inject the messages into instance 2. It will connect to instance 1,
 # and that instance will record the data.
-tcpflood -m$NUMMESSAGES -i1
-wait_file_lines
+injectmsg
 # shut down sender when everything is sent, receiver continues to run concurrently
 shutdown_when_empty 2
 wait_shutdown 2
@@ -53,5 +44,5 @@ wait_shutdown 2
 shutdown_when_empty
 wait_shutdown
 
-seq_check 1 $NUMMESSAGES
+seq_check
 exit_test
